# -*- coding: utf-8 -*-
# Generated by Django 1.11.21 on 2019-06-17 07:43
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sampleapp', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='foo',
            name='yesorno',
            field=models.BooleanField(default=True, verbose_name='Check for yes'),
        ),
    ]
