# -*- coding: utf-8 -*-
# Generated by Django 1.11.21 on 2019-06-14 04:38
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Bar",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("name", models.CharField(max_length=100)),
            ],
        ),
        migrations.CreateModel(
            name="Baz",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("name", models.CharField(max_length=100)),
            ],
        ),
        migrations.CreateModel(
            name="Foo",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("name", models.CharField(max_length=100, verbose_name="Name of this instance")),
                ("integer", models.IntegerField(verbose_name="Type your favorite integer")),
                (
                    "choose_somthing",
                    models.CharField(
                        choices=[("ok", "It's OK"), ("nok", "It's not OK")],
                        default="ok",
                        max_length=100,
                        verbose_name="Make your choice",
                    ),
                ),
                (
                    "bar",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="sampleapp.Bar",
                        verbose_name="Name of the bar",
                    ),
                ),
                ("baz", models.ManyToManyField(blank=True, to="sampleapp.Baz", verbose_name="Select some baz")),
            ],
        ),
    ]
